@@ -64,7 +64,7 @@ public class Subroutines {
     /**
      * This inner class implements the Subroutine interface.
      */
-    private class SubroutineImpl implements Subroutine {
+    private final class SubroutineImpl implements Subroutine {
         /**
          * UNSET, a symbol for an uninitialized localVariable field. This is used for the "top-level" Subroutine; i.e. no
          * subroutine.
@@ -98,23 +98,6 @@ public class Subroutines {
         public SubroutineImpl() {
         }
 
-        /**
-         * A recursive helper method for getRecursivelyAccessedLocalsIndices().
-         *
-         * @see #getRecursivelyAccessedLocalsIndices()
-         */
-        private void _getRecursivelyAccessedLocalsIndicesHelper(final Set<Integer> set, final Subroutine[] subs) {
-            for (final Subroutine sub : subs) {
-                final int[] lvs = sub.getAccessedLocalsIndices();
-                for (final int lv : lvs) {
-                    set.add(Integer.valueOf(lv));
-                }
-                if (sub.subSubs().length != 0) {
-                    _getRecursivelyAccessedLocalsIndicesHelper(set, sub.subSubs());
-                }
-            }
-        }
-
         /**
          * Adds a new JSR or JSR_W that has this subroutine as its target.
          */
@@ -236,7 +219,7 @@ public class Subroutines {
             for (final int lv : lvs) {
                 s.add(Integer.valueOf(lv));
             }
-            _getRecursivelyAccessedLocalsIndicesHelper(s, this.subSubs());
+            getRecursivelyAccessedLocalsIndicesHelper(s, this.subSubs());
             final int[] ret = new int[s.size()];
             int j = -1;
             for (final Integer index : s) {
@@ -246,6 +229,23 @@ public class Subroutines {
             return ret;
         }
 
+        /**
+         * A recursive helper method for getRecursivelyAccessedLocalsIndices().
+         *
+         * @see #getRecursivelyAccessedLocalsIndices()
+         */
+        private void getRecursivelyAccessedLocalsIndicesHelper(final Set<Integer> set, final Subroutine[] subs) {
+            for (final Subroutine sub : subs) {
+                final int[] lvs = sub.getAccessedLocalsIndices();
+                for (final int lv : lvs) {
+                    set.add(Integer.valueOf(lv));
+                }
+                if (sub.subSubs().length != 0) {
+                    getRecursivelyAccessedLocalsIndicesHelper(set, sub.subSubs());
+                }
+            }
+        }
+
         /**
          * Sets the leaving RET instruction. Must be invoked after all instructions are added. Must not be invoked for top-level
          * 'subroutine'.
@@ -332,7 +332,7 @@ public class Subroutines {
             return ret.toString();
         }
 
-    }// end Inner Class SubrouteImpl
+    } // end Inner Class SubrouteImpl
 
     /**
      * A utility method that calculates the successors of a given InstructionHandle <B>in the same subroutine</B>. That
@@ -510,7 +510,7 @@ public class Subroutines {
                     instructionsAssigned.add(element);
                 }
             }
-            if (actual != all[0]) {// If we don't deal with the top-level 'subroutine'
+            if (actual != all[0]) { // If we don't deal with the top-level 'subroutine'
                 ((SubroutineImpl) getSubroutine(actual)).setLeavingRET();
             }
         }
@@ -519,16 +519,16 @@ public class Subroutines {
             // Now make sure no instruction of a Subroutine is protected by exception handling code
             // as is mandated by JustIces notion of subroutines.
             for (final CodeExceptionGen handler : handlers) {
-                InstructionHandle _protected = handler.getStartPC();
-                while (_protected != handler.getEndPC().getNext()) {
+                InstructionHandle protectedIh = handler.getStartPC();
+                while (protectedIh != handler.getEndPC().getNext()) {
                     // Note the inclusive/inclusive notation of "generic API" exception handlers!
                     for (final Subroutine sub : subroutines.values()) {
-                        if (sub != subroutines.get(all[0]) && sub.contains(_protected)) {
-                            throw new StructuralCodeConstraintException("Subroutine instruction '" + _protected + "' is protected by an exception handler, '"
+                        if (sub != subroutines.get(all[0]) && sub.contains(protectedIh)) {
+                            throw new StructuralCodeConstraintException("Subroutine instruction '" + protectedIh + "' is protected by an exception handler, '"
                                 + handler + "'. This is forbidden by the JustIce verifier due to its clear definition of subroutines.");
                         }
                     }
-                    _protected = _protected.getNext();
+                    protectedIh = protectedIh.getNext();
                 }
             }
         }
